# The FHIR Data Tabulation Package
This package contains functions to use a schema to read data from a FHIR server, and write it to a tabular format. Details about what a schema is, and what it is intended to do is described in detail in the [README.md](/phdi/tabulation/README.md) for the `phdi.tabulation` package. Details on use are documented in the [tabulation tutorial](/tutorials/tabulation-tutorial.md).
